Index: trunk/tools/warp_inputs.pl
===================================================================
--- trunk/tools/warp_inputs.pl	(revision 20728)
+++ trunk/tools/warp_inputs.pl	(revision 21427)
@@ -14,5 +14,5 @@
 use constant IMAGE => '.ch.fits';  # Image extension
 use constant MASK => '.ch.mk.fits'; # Mask extension
-use constant WEIGHT => '.ch.wt.fits'; # Weight extension
+use constant VARIANCE => '.ch.wt.fits'; # Variance extension
 use constant ASTROM => '.smf';  # Astrometry extension
 
@@ -22,5 +22,5 @@
 my ($warp_id);                  # Warp of interest
 my ($skycell_id);               # Skycell of interest
-my ($image, $mask, $weight); # Files to contain input lists
+my ($image, $mask, $variance); # Files to contain input lists
 
 GetOptions(
@@ -33,5 +33,5 @@
            'image=s' => \$image, # File with images
            'mask=s' => \$mask,  # File with masks
-           'weight=s' => \$weight, # File with weights
+           'variance=s' => \$variance, # File with variances
            ) or die "Unable to parse arguments.\n";
 die "Unknown option: @ARGV\n" if @ARGV;
@@ -69,8 +69,8 @@
 $db->disconnect;
 
-my ($imageList, $maskList, $weightList); # Files to write to
+my ($imageList, $maskList, $varianceList); # Files to write to
 open $imageList, "> $image" if defined $image;
 open $maskList, "> $mask" if defined $mask;
-open $weightList, "> $weight" if defined $weight;
+open $varianceList, "> $variance" if defined $variance;
 
 foreach my $row ( @$results ) {
@@ -83,14 +83,14 @@
     my $imageName = $chip . IMAGE(); # Name of image
     my $maskName = $chip . MASK(); # Name of mask
-    my $weightName = $chip . WEIGHT(); # Name of weight
+    my $varianceName = $chip . VARIANCE(); # Name of variance
     my $astromName = $cam . ASTROM(); # Name of astrometry
 
     print $imageList "$imageName\n" if defined $image;
     print $maskList "$maskName\n" if defined $mask;
-    print $weightList "$weightName\n" if defined $weight;
+    print $varianceList "$varianceName\n" if defined $variance;
 
     copy_file( $imageName );
     copy_file( $maskName );
-    copy_file( $weightName );
+    copy_file( $varianceName );
     copy_file( $astromName );
 }
@@ -98,5 +98,5 @@
 close $imageList if defined $image;
 close $maskList if defined $mask;
-close $weightList if defined $weight;
+close $varianceList if defined $variance;
 
 
